<div class="warning">

### This page is under construction. Images will be added soon.

</div>

# Mobile Robots

The Space Robotics Bench provides various mobile robots, including legged robots, wheeled platforms, aerial vehicles, and spacecraft.

## Wheeled Robots

#### Leo Rover (`leo_rover`)

<!-- #### Mars Rover (`mars_rover`) -->

#### Perseverance (`perseverance`)

#### Pragyan (`pragyan`)

## Legged Robots

### Bipeds

#### Cassie (`cassie`)

### Quadrupeds

#### ANYmal C (`anymal_c`)

#### ANYmal D (`anymal_d`)

#### Random ANYmal Quadruped (`random_anymal_quadruped`) \[Randomized\]

#### Spot (`spot`)

#### Unitree A1 (`unitree_a1`)

#### Unitree Go1 (`unitree_go1`)

#### Unitree Go2 (`unitree_go2`)

#### Random Unitree Quadruped (`random_unitree_quadruped`) \[Randomized\]

## Aerial Robots

### Multicopters

#### Crazyflie (`crazyflie`)

#### Ingenuity (`ingenuity`)

## Orbital Robots

### Spacecraft

#### CubeSat (`cubesat`) \[Procedural\]

#### Venus Express (`venus_express`)

#### Lunar Gateway (`gateway`)

#### Starship (`starship`)

#### Super Heavy (`super_heavy`)

### Lander

#### Apollo Lander (`apollo_lander`)

#### Peregrine Lander (`peregrine_lander`)

#### Vikram Lander (`vikram_lander`)

#### Resilience Lander (`resilience_lander`)

#### Random Lander (`random_lander`) \[Randomized\]
